Your message dated Mon, 23 Oct 2006 11:32:57 -0700
with message-id <[EMAIL PROTECTED]>
and subject line Bug#394535: fixed in lphdisk 0.9.1-2
has caused the attached Bug report to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what I am
talking about this indicates a serious mail system misconfiguration
somewhere.  Please contact me immediately.)

Debian bug tracking system administrator
(administrator, Debian Bugs database)

--- Begin Message ---
Package: lphdisk
Version: 0.9.1-1
Severity: normal
Tags: patch

lphdisk does not build with linux-kernel-headers >= 2.6.18 due to the
_syscall* macros being no longer available. It results in the following
build failure:

> cc -g -Wall -O2   -c -o lphdisk.o lphdisk.c
> lphdisk.c:117: error: expected declaration specifiers or ‘...’ before 
> ‘_llseek’
> lphdisk.c:117: error: expected declaration specifiers or ‘...’ before ‘fd’
> lphdisk.c:117: error: expected declaration specifiers or ‘...’ before 
> ‘offset_high’
<snip/>

Patch attached.

-Ted

-- System Information:
Debian Release: testing/unstable
  APT prefers unstable
  APT policy: (500, 'unstable'), (1, 'experimental')
Architecture: i386 (i686)
Shell:  /bin/sh linked to /bin/dash
Kernel: Linux 2.6.17-2-k7
Locale: LANG=de_DE.UTF-8, LC_CTYPE=de_DE.UTF-8 (charmap=UTF-8)
diff -ru lphdisk-0.9.1/lphdisk.c lphdisk-0.9.1-new/lphdisk.c
--- lphdisk-0.9.1/lphdisk.c	2006-10-22 04:16:27.000000000 +1000
+++ lphdisk-0.9.1-new/lphdisk.c	2006-10-22 04:15:14.000000000 +1000
@@ -105,18 +105,17 @@
 /* call to do seeks to "long long" offsets under linux (this is needed to    */
 /* seek to sectors beyond 4194303 (2GB)).  This isn't directly supported by  */
 /* glibc, so we need to make our own interface function for it.  We should   */
 /* be able to get the _NR__llseek define from linux/unistd.h.  From this we  */
 /* can construct a wrapper to perform the right system call.                 */
 
-#include <linux/unistd.h>       /* for __NR__llseek */
+#include <sys/syscall.h>       /* for SYS__llseek */
 
 typedef long long lloff_t;
 
-#ifdef __NR__llseek
+#ifdef SYS__llseek
 
-static _syscall5(int,_llseek, unsigned int,fd, unsigned long,offset_high,
-                 unsigned long,offset_low, lloff_t *,result,
-                 unsigned int,origin)
+#define _llseek(fd, offset_high, offset_low, result, origin) \
+	syscall(SYS__llseek, fd, offset_high, offset_low, result, origin)
 
 lloff_t llseek (unsigned int fd, lloff_t offset, unsigned int origin) {
   lloff_t result;
@@ -128,9 +127,9 @@
   return (retval == -1 ? (lloff_t) retval : result);
 }
 
-#else /* __NR__llseek */
+#else /* SYS__llseek */
 
 /* Somehow, __NR__llseek wasn't in linux/unistd.h.  This shouldn't ever      */
 /* happen, but better safe than sorry.. The best we can do is emulate it     */
 /* with lseek, and hope we don't get an offset that's too large (throw an    */
 /* error if we do)                                                           */
@@ -148,7 +147,7 @@
   }
 }
 
-#endif /* __NR__llseek */
+#endif /* SYS__llseek */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 

--- End Message ---
--- Begin Message ---
Source: lphdisk
Source-Version: 0.9.1-2

We believe that the bug you reported is fixed in the latest version of
lphdisk, which is due to be installed in the Debian FTP archive:

lphdisk_0.9.1-2.diff.gz
  to pool/main/l/lphdisk/lphdisk_0.9.1-2.diff.gz
lphdisk_0.9.1-2.dsc
  to pool/main/l/lphdisk/lphdisk_0.9.1-2.dsc
lphdisk_0.9.1-2_i386.deb
  to pool/main/l/lphdisk/lphdisk_0.9.1-2_i386.deb



A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to [EMAIL PROTECTED],
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Roberto Lumbreras <[EMAIL PROTECTED]> (supplier of updated lphdisk package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [EMAIL PROTECTED])


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Format: 1.7
Date: Mon, 23 Oct 2006 17:31:14 +0200
Source: lphdisk
Binary: lphdisk
Architecture: source i386
Version: 0.9.1-2
Distribution: unstable
Urgency: low
Maintainer: Roberto Lumbreras <[EMAIL PROTECTED]>
Changed-By: Roberto Lumbreras <[EMAIL PROTECTED]>
Description: 
 lphdisk    - prepares hibernation partition for Phoenix NoteBIOS
Closes: 394535
Changes: 
 lphdisk (0.9.1-2) unstable; urgency=low
 .
   * Fix FTBFS because old syscall usage. (closes: #394535)
     Apply patch so lphdisk compiles with new kernel headers;
     Build-depend on linux-kernel-headers >= 2.6.18.
Files: 
 5a9db4564da099a503f181f7f714bbbb 600 admin extra lphdisk_0.9.1-2.dsc
 0cac86da4309a19e42fe795024e88126 3752 admin extra lphdisk_0.9.1-2.diff.gz
 a53e130e67e8b50a9b08ed08e045616d 21742 admin extra lphdisk_0.9.1-2_i386.deb

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.5 (GNU/Linux)

iD8DBQFFPQcOfIEQE/XJcI0RAttgAKCKpul0/OKB1NyXNag3xGuydvKp9gCgpuKX
wnldgnyIuqLwixjs91Xawdw=
=xZ7L
-----END PGP SIGNATURE-----


--- End Message ---
@@ -105,18 +105,17 @@
 /* seek to sectors beyond 4194303 (2GB)).  This isn't directly supported by  */
 /* glibc, so we need to make our own interface function for it.  We should   */
-/* be able to get the _NR__llseek define from linux/unistd.h.  From this we  */
+/* be able to get the SYS__llseek define from sys/syscall.h.  From this we  */
 /* can construct a wrapper to perform the right system call.                 */
 
@@ -128,9 +127,9 @@
 
-/* Somehow, __NR__llseek wasn't in linux/unistd.h.  This shouldn't ever      */
+/* Somehow, SYS__llseek wasn't in sys/syscall.h.  This shouldn't ever      */
 /* happen, but better safe than sorry.. The best we can do is emulate it     */
 /* with lseek, and hope we don't get an offset that's too large (throw an    */

Reply via email to